@@ -4,7 +4,7 @@
 #include <kstddirs.h>
 
 #include <tdeconfig.h>
-#include <tqdatetm.h>
+#include <tqdatetime.h>
 #include <tqtimer.h>
 #include <tqevent.h>
 #include <tqcolor.h>
@@ -770,13 +770,13 @@ void Referee::eaten()
                       pix->rect(pacman->position(), MonsterScorePix, monstersEaten-1)));
 
     if (--timerCount > 0)
-        TQTimer::singleShot( monsterScoreDurMS, this, SLOT(eaten()));
+        TQTimer::singleShot( monsterScoreDurMS, this, TQ_SLOT(eaten()));
     else {
         for (Monster *m = monsters->first(); m != 0; m = monsters->next())
             if (m && m->direction() == X && !gameState.testBit(Introducing))
                 m->setDirection(N);
         if (monstersEaten != 4 || !gameState.testBit(Introducing))
-            TQTimer::singleShot( monsterScoreDurMS, this, SLOT(start()));
+            TQTimer::singleShot( monsterScoreDurMS, this, TQ_SLOT(start()));
     }
 }
 
@@ -918,14 +918,14 @@ void Referee::introPlay()
     if (!gameState.testBit(Introducing) || gameState.testBit(Ready))
         return;
     if (gameState.testBit(Paused) || gameState.testBit(HallOfFame)) {
-        TQTimer::singleShot(afterPauseMS, this, SLOT(introPlay()));
+        TQTimer::singleShot(afterPauseMS, this, TQ_SLOT(introPlay()));
         return;
     }
 
     if (!gameState.testBit(Init)) {
         if (monstersEaten == 4) {
             stop();
-            TQTimer::singleShot(introPostAnimationMS, this, SLOT(demo()));
+            TQTimer::singleShot(introPostAnimationMS, this, TQ_SLOT(demo()));
         }
         if (pacman->direction() == W) {
             int id = -1;
@@ -984,7 +984,7 @@ void Referee::introPlay()
     }
 
     if (timerCount++ < 15)
-        TQTimer::singleShot(introAnimationMS, this, SLOT(introPlay()));
+        TQTimer::singleShot(introAnimationMS, this, TQ_SLOT(introPlay()));
 }
 
 void Referee::demo()
@@ -993,7 +993,7 @@ void Referee::demo()
         return;
 
     if (gameState.testBit(Paused) || gameState.testBit(HallOfFame)) {   
-        TQTimer::singleShot(afterPauseMS, this, SLOT(demo()));
+        TQTimer::singleShot(afterPauseMS, this, TQ_SLOT(demo()));
         return;
     }
 
@@ -1020,7 +1020,7 @@ void Referee::demo()
     repaint();
 
     timerCount = 0;
-    TQTimer::singleShot(playerDurMS, this, SLOT(start()));
+    TQTimer::singleShot(playerDurMS, this, TQ_SLOT(start()));
 }
 
 void Referee::play()
@@ -1061,13 +1061,13 @@ void Referee::play()
     repaint(pix->rect(board->position(fruithome), i18n("READY!")), FALSE);
 
     timerCount = 0;
-    TQTimer::singleShot(playerDurMS, this, SLOT(ready()));
+    TQTimer::singleShot(playerDurMS, this, TQ_SLOT(ready()));
 }
 
 void Referee::ready()
 {
     if (gameState.testBit(Paused) || gameState.testBit(HallOfFame)) {
-        TQTimer::singleShot(afterPauseMS, this, SLOT(ready()));
+        TQTimer::singleShot(afterPauseMS, this, TQ_SLOT(ready()));
         return;
     }
 
@@ -1077,7 +1077,7 @@ void Referee::ready()
         gameState.clearBit(Init);
         repaint(pix->rect(board->position(monsterhome, 0), i18n("PLAYER ONE")), FALSE);
         repaintFigures();
-        TQTimer::singleShot(playerDurMS, this, SLOT(ready()));
+        TQTimer::singleShot(playerDurMS, this, TQ_SLOT(ready()));
         return;
     }
 
@@ -1089,7 +1089,7 @@ void Referee::ready()
         gameState.setBit(Ready);
         gameState.clearBit(Init);
         repaint(pix->rect(board->position(fruithome), i18n("READY!")), FALSE);
-        TQTimer::singleShot(readyDurMS, this, SLOT(ready()));
+        TQTimer::singleShot(readyDurMS, this, TQ_SLOT(ready()));
     }
 }
 
@@ -1104,7 +1104,7 @@ void Referee::levelUp()
     repaint(pix->rect(pacman->position(), PacmanPix));
 
     timerCount = 0;
-    TQTimer::singleShot(levelUpPreAnimationMS, this, SLOT(levelUpPlay()));
+    TQTimer::singleShot(levelUpPreAnimationMS, this, TQ_SLOT(levelUpPlay()));
 }
 
 void Referee::levelUpPlay()
@@ -1113,7 +1113,7 @@ void Referee::levelUpPlay()
         return;
 
     if (gameState.testBit(Paused) || gameState.testBit(HallOfFame)) {
-        TQTimer::singleShot(afterPauseMS, this, SLOT(levelUpPlay()));
+        TQTimer::singleShot(afterPauseMS, this, TQ_SLOT(levelUpPlay()));
         return;
     }
 
@@ -1128,7 +1128,7 @@ void Referee::levelUpPlay()
     }
 
     if (timerCount++ < 2) {
-        TQTimer::singleShot(levelUpAnimationMS, this, SLOT(levelUpPlay()));
+        TQTimer::singleShot(levelUpAnimationMS, this, TQ_SLOT(levelUpPlay()));
         return;
     }
 
@@ -1162,7 +1162,7 @@ void Referee::start()
         return;
 
     if (gameState.testBit(Paused) || gameState.testBit(HallOfFame)) {
-        TQTimer::singleShot(afterPauseMS, this, SLOT(start()));
+        TQTimer::singleShot(afterPauseMS, this, TQ_SLOT(start()));
         return;
     }
 
@@ -1212,11 +1212,11 @@ void Referee::killed()
         for (Monster *m = monsters->first(); m != 0; m = monsters->next())
             if (m)
                 m->setDirection(X);
-        TQTimer::singleShot(dyingPreAnimationMS, this, SLOT(killed()));
+        TQTimer::singleShot(dyingPreAnimationMS, this, TQ_SLOT(killed()));
     } else {
         stop();
         if (gameState.testBit(Paused) || gameState.testBit(HallOfFame)) {
-            TQTimer::singleShot(afterPauseMS, this, SLOT(killed()));
+            TQTimer::singleShot(afterPauseMS, this, TQ_SLOT(killed()));
             return;
         }
 
@@ -1234,16 +1234,16 @@ void Referee::killedPlay()
     if (!gameState.testBit(Dying) || gameState.testBit(Ready))
         return;
     if (gameState.testBit(Paused) || gameState.testBit(HallOfFame)) {
-        TQTimer::singleShot(afterPauseMS, this, SLOT(killedPlay()));
+        TQTimer::singleShot(afterPauseMS, this, TQ_SLOT(killedPlay()));
         return;
     }
 
     if (timerCount <= pix->maxPixmaps(DyingPix)) {
         repaint(pix->rect(pacman->position(), PacmanPix), FALSE);
         if (timerCount >= pix->maxPixmaps(DyingPix)-1 || timerCount == 0)
-            TQTimer::singleShot(dyingPostAnimationMS, this, SLOT(killedPlay()));
+            TQTimer::singleShot(dyingPostAnimationMS, this, TQ_SLOT(killedPlay()));
         else
-            TQTimer::singleShot(dyingAnimationMS, this, SLOT(killedPlay()));
+            TQTimer::singleShot(dyingAnimationMS, this, TQ_SLOT(killedPlay()));
         timerCount++;
     } else {
         gameState.clearBit(Dying);
@@ -1256,7 +1256,7 @@ void Referee::killedPlay()
                 repaint(pix->rect(board->position(energizer, e), EnergizerPix), FALSE);
             }
             repaint(pix->rect(board->position(fruithome), i18n("GAME  OVER")), FALSE);
-            TQTimer::singleShot(gameOverDurMS, this, SLOT(hallOfFame()));
+            TQTimer::singleShot(gameOverDurMS, this, TQ_SLOT(hallOfFame()));
         } else {
             gameState.clearBit(Init);
             initPacman();
